Documentation
¶
Index ¶
- func NewKubeCoreCache(ctx context.Context, client kubernetes.Interface) (*kubeCoreCaches, error)
- func NewKubeCoreCacheWithOptions(ctx context.Context, client kubernetes.Interface, resyncDuration time.Duration, ...) (*kubeCoreCaches, error)
- func NewKubeDeploymentCache(ctx context.Context, client kubernetes.Interface) (*kubeDeploymentCache, error)
- type Cache
- type ConfigMapLister
- type KubeCoreCache
- type KubeDeploymentCache
- type PodLister
- type SecretLister
- type ServiceLister
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewKubeCoreCache ¶
func NewKubeCoreCache(ctx context.Context, client kubernetes.Interface) (*kubeCoreCaches, error)
This context should live as long as the cache is desired. i.e. if the cache is shared across clients, it should get a context that has a longer lifetime than the clients themselves
func NewKubeCoreCacheWithOptions ¶ added in v0.10.8
func NewKubeDeploymentCache ¶
func NewKubeDeploymentCache(ctx context.Context, client kubernetes.Interface) (*kubeDeploymentCache, error)
This context should live as long as the cache is desired. i.e. if the cache is shared across clients, it should get a context that has a longer lifetime than the clients themselves
Types ¶
type ConfigMapLister ¶ added in v0.10.8
type KubeCoreCache ¶
type KubeCoreCache interface {
Cache
// Deprecated: Use NamespacedPodLister instead
PodLister() kubelisters.PodLister
// Deprecated: Use NamespacedServiceLister instead
ServiceLister() kubelisters.ServiceLister
// Deprecated: Use NamespacedConfigMapLister instead
ConfigMapLister() kubelisters.ConfigMapLister
// Deprecated: Use NamespacedSecretLister instead
SecretLister() kubelisters.SecretLister
NamespaceLister() kubelisters.NamespaceLister
NamespacedPodLister(ns string) PodLister
NamespacedServiceLister(ns string) ServiceLister
NamespacedConfigMapLister(ns string) ConfigMapLister
NamespacedSecretLister(ns string) SecretLister
}
type KubeDeploymentCache ¶
type KubeDeploymentCache interface {
DeploymentLister() kubelisters.DeploymentLister
Subscribe() <-chan struct{}
Unsubscribe(<-chan struct{})
}
type SecretLister ¶ added in v0.10.8
Click to show internal directories.
Click to hide internal directories.